@@ -1,4 +1,6 @@
 from django.db import models
+from exchange.managers import ExchangeRateManager
+from exchange.iso_4217 import code_list
 
 
 class Currency(models.Model):
@@ -12,6 +14,9 @@ class Currency(models.Model):
     def __unicode__(self):
         return self.code
 
+    def get_numeric_code(self):
+        return code_list[self.code]  # Let it raise an exception
+
 
 class ExchangeRate(models.Model):
     """Model to persist exchange rates between currencies"""
@@ -19,5 +24,7 @@ class ExchangeRate(models.Model):
     target = models.ForeignKey('exchange.Currency')
     rate = models.DecimalField(max_digits=12, decimal_places=2)
 
+    objects = ExchangeRateManager()
+
     def __unicode__(self):
         return '%s / %s = %s' % (self.source, self.target, self.rate)
